package com.ruoyi.tcZz.mapper;

import java.util.List;
import com.ruoyi.tcZz.domain.TcQlzxxddt;
import org.apache.ibatis.annotations.Param;

/**
 * 清朗专项行动动态Mapper接口
 * 
 * @author ruoyi
 * @date 2023-10-13
 */
public interface TcQlzxxddtMapper 
{
    /**
     * 查询清朗专项行动动态
     * 
     * @param id 清朗专项行动动态主键
     * @return 清朗专项行动动态
     */
    public TcQlzxxddt selectTcQlzxxddtById(Long id);

    /**
     * 查询清朗专项行动动态列表
     * 
     * @param tcQlzxxddt 清朗专项行动动态
     * @return 清朗专项行动动态集合
     */
    public List<TcQlzxxddt> selectTcQlzxxddtList(TcQlzxxddt tcQlzxxddt);

    /**
     * 新增清朗专项行动动态
     * 
     * @param tcQlzxxddt 清朗专项行动动态
     * @return 结果
     */
    public int insertTcQlzxxddt(TcQlzxxddt tcQlzxxddt);

    /**
     * 修改清朗专项行动动态
     * 
     * @param tcQlzxxddt 清朗专项行动动态
     * @return 结果
     */
    public int updateTcQlzxxddt(TcQlzxxddt tcQlzxxddt);

    /**
     * 删除清朗专项行动动态
     * 
     * @param id 清朗专项行动动态主键
     * @return 结果
     */
    public int deleteTcQlzxxddtById(Long id);

    /**
     * 批量删除清朗专项行动动态
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTcQlzxxddtByIds(Long[] ids);

    /**
     * 批量启用禁用
     *
     *
     */
    public void updateByisStatus(@Param("isStatus") Integer isStatus, @Param("ids") List<String> ids);
}
