package com.ruoyi.tcZz.controller;

import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.tcZz.domain.TcAqg;
import com.ruoyi.tcZz.domain.TcMtlx;
import com.ruoyi.tcZz.domain.TcQlzxxddt;
import com.ruoyi.tcZz.service.ITcQlzxxddtService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 清朗专项行动动态Controller
 *
 * @author ruoyi
 * @date 2023-10-13
 */
@RestController
@Api(tags = "清朗专项行动动态")
@RequestMapping("/tcZz/netManage/qlzxxddt")
public class TcQlzxxddtController extends BaseController {
    @Autowired
    private ITcQlzxxddtService tcQlzxxddtService;

    /**
     * 查询清朗专项行动动态列表
     */
    @ApiOperation(value = "查询清朗专项行动动态列表", response = TcQlzxxddt.class)
    @GetMapping("/list")
    public TableDataInfo list(TcQlzxxddt tcQlzxxddt) {
        startPage();
        List<TcQlzxxddt> list = tcQlzxxddtService.selectTcQlzxxddtList(tcQlzxxddt);
        return getDataTable(list);
    }

    /**
     * 导出清朗专项行动动态列表
     */
    @ApiOperation(value = "导出清朗专项行动动态列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcQlzxxddt tcQlzxxddt) {
        List<TcQlzxxddt> list = tcQlzxxddtService.selectTcQlzxxddtList(tcQlzxxddt);
        ExcelUtil<TcQlzxxddt> util = new ExcelUtil<TcQlzxxddt>(TcQlzxxddt.class);
        util.exportExcel(response, list, "清朗专项行动动态数据");
    }

    /**
     * 获取清朗专项行动动态详细信息
     */
    @ApiOperation(value = "获取清朗专项行动动态详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(tcQlzxxddtService.selectTcQlzxxddtById(id));
    }

    /**
     * 新增清朗专项行动动态
     */
    @ApiOperation(value = "新增清朗专项行动动态")
    @PostMapping
    public AjaxResult add(@RequestBody TcQlzxxddt tcQlzxxddt) {
        return toAjax(tcQlzxxddtService.insertTcQlzxxddt(tcQlzxxddt));
    }

    /**
     * 修改清朗专项行动动态
     */
    @ApiOperation(value = "修改清朗专项行动动态")
    @PutMapping
    public AjaxResult edit(@RequestBody TcQlzxxddt tcQlzxxddt) {
        return toAjax(tcQlzxxddtService.updateTcQlzxxddt(tcQlzxxddt));
    }

    /**
     * 删除清朗专项行动动态
     */
    @ApiOperation(value = "删除清朗专项行动动态")
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tcQlzxxddtService.deleteTcQlzxxddtByIds(ids));
    }


    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcQlzxxddt> util = new ExcelUtil<TcQlzxxddt>(TcQlzxxddt.class);
        List<TcQlzxxddt> tcQlzxxddtList = util.importExcel(file.getInputStream());
        tcQlzxxddtService.importUser(tcQlzxxddtList);
        return AjaxResult.success();
    }

    /**
     * 批量启用禁用
     *
     * @param isStatus 启用禁用状态
     * @return
     */

    @ApiOperation("批量启用禁用")
    @GetMapping("/isStatus")
    public AjaxResult isStatus(@RequestParam("isStatus") Integer isStatus, @RequestParam("ids") List<String> ids) {
        tcQlzxxddtService.updateByisStatus(isStatus,ids);
        return AjaxResult.success();
    }

    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<TcQlzxxddt> util = new ExcelUtil<TcQlzxxddt>(TcQlzxxddt.class);
        util.importTemplateExcel(response, " 清朗专项行动动态");
    }
}
